@@ -22,14 +22,19 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/program.h>
+#endif
+
 namespace Glom
 {
 
 Notebook_Data::Notebook_Data()
-: m_iPage_Details(0), m_iPage_List(0)
+: 
   #ifdef GLOM_ENABLE_MAEMO
-  , m_window_maemo_details(0)
+  m_window_maemo_details(0),
   #endif
+  m_iPage_Details(0), m_iPage_List(0)
 {
   //Add Pages:
   pages().push_back(Gtk::Notebook_Helpers::TabElem(m_Box_List, _("List")));
@@ -42,9 +47,16 @@ Notebook_Data::Notebook_Data()
   //On Maemo, we add the box to m_window_maemo_details instead:
   m_window_maemo_details = new Window_BoxHolder(&m_Box_Details, _("Details"));
   
+  //Let this window have the main AppMenu:
+  Hildon::Program::get_instance()->add_window(*m_window_maemo_details);
+  
   Gtk::Window* pWindow = get_app_window();
   if(pWindow)
     m_window_maemo_details->set_transient_for(*pWindow);
+    
+  //Refresh the list when the details window is closed:
+  m_window_maemo_details->signal_hide().connect(
+    sigc::mem_fun(*this, &Notebook_Data::on_window_maemo_details_closed));
 
   m_Box_Details.show_all();
   #endif //GLOM_ENABLE_MAEMO
@@ -102,6 +114,16 @@ Notebook_Data::~Notebook_Data()
 #endif //GLOM_ENABLE_MAEMO
 }
 
+#ifdef GLOM_ENABLE_MAEMO
+void Notebook_Data::on_window_maemo_details_closed()
+{
+  //Show the changed record in the list:
+  const Gnome::Gda::Value primary_key_selected = m_Box_List.get_primary_key_value_selected();
+  m_Box_List.refresh_data_from_database();
+  m_Box_List.set_primary_key_value_selected(primary_key_selected);
+}
+#endif //GLOM_ENABLE_MAEMO
+
 bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value_for_details)
 {
   m_table_name = found_set.m_table_name;
@@ -222,7 +244,15 @@ void Notebook_Data::show_details(const Gnome::Gda::Value& primary_key_value)
 
 #if GLOM_ENABLE_MAEMO
   //Details are shown in a separate window on Maemo,
-  //though that window contains the regular m_Box_Details.
+  //though that window contains the regular m_Box_Details. 
+  //TODO: Use the singular form when it's available from the document.
+  Document* document = get_document();
+  g_assert(document);
+  const Glib::ustring title = 
+    Glib::ustring::compose(_("%1 Details"), 
+      document->get_table_title_singular(m_table_name));
+  m_window_maemo_details->set_title(title);
+  
   m_window_maemo_details->show();
 #else  
   if(get_current_view() != DATA_VIEW_Details)
@@ -372,4 +402,12 @@ void Notebook_Data::get_record_counts(gulong& total, gulong& found)
   m_Box_List.get_record_counts(total, found);
 }
 
+#ifdef GLOM_ENABLE_MAEMO
+void Notebook_Data::do_menu_file_add_record()
+{
+  show_details(Gnome::Gda::Value());
+  m_Box_Details.do_new_record();
+}
+#endif //GLOM_ENABLE_MAEMO
+
 } //namespace Glom
