@@ -34,16 +34,6 @@
 namespace Glom
 {
 
-ComboGlom::ComboGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
-: Gtk::ComboBox(cobject)
-{
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  setup_menu();
-#endif // !GLOM_ENABLE_CLIENT_ONLY
-
-  init();
-}
-
 ComboGlom::ComboGlom()
 : ComboGlomChoicesBase()
 {
@@ -66,16 +56,34 @@ ComboGlom::ComboGlom(const sharedptr<LayoutItem_Field>& field_second)
 
 void ComboGlom::init()
 {
+  #ifndef GLOM_ENABLE_MAEMO
   set_model(m_refModel);
-
   pack_start(m_Columns.m_col_first);
+  #else
+  //Maemo:
+  set_selector(m_maemo_selector);
+  m_maemo_selector.set_model(0, m_refModel);
+  
+  Glib::RefPtr<Hildon::TouchSelectorColumn> column =
+    m_maemo_selector.append_text_column(m_refModel);
+  column->set_property("text-column", 0); // TODO: Add a TextSelectorColumn::set_text_column() method?
 
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
+  column->pack_start(m_Columns.m_col_first, false);
+  #endif //GLOM_ENABLE_MAEMO
+
+
+
+  #ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
+  #ifndef GLOM_ENABLE_MAEMO
   signal_changed().connect(sigc::mem_fun(*this, &ComboGlom::on_changed));
-#endif // GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
+  #else
+  m_maemo_selector.signal_changed().connect(sigc::mem_fun(*this, &ComboGlom::on_changed));
+  #endif // GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
+  #endif //GLOM_ENABLE_MAEMO
 
   if(m_with_second)
   {
+    #ifndef GLOM_ENABLE_MAEMO
     //We don't use this convenience method, because we want more control over the renderer.
     //and CellLayout gives no way to get the renderer back afterwards.
     //(well, maybe set_cell_data_func(), but that's a bit awkward.)
@@ -88,11 +96,15 @@ void ComboGlom::init()
     pack_start(*cell_second);
 
     //Make the renderer render the column:
-#ifdef GLIBMM_PROPERTIES_ENABLED
+    #ifdef GLIBMM_PROPERTIES_ENABLED
     add_attribute(cell_second->_property_renderable(), m_Columns.m_col_second);
-#else
+    #else
     add_attribute(*cell_second, cell_second->_property_renderable(), m_Columns.m_col_second);
-#endif
+    #endif
+    #else
+    //Maemo:
+    column->pack_start(m_Columns.m_col_second);
+    #endif //GLOM_ENABLE_MAEMO
   }
 
   //if(m_glom_type == Field::TYPE_NUMERIC)
@@ -137,8 +149,32 @@ void ComboGlom::check_for_change()
 void ComboGlom::set_value(const Gnome::Gda::Value& value)
 {
   sharedptr<const LayoutItem_Field> layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
-  if(layout_item)
-    set_text(Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format));
+  if(!layout_item)
+    return;
+
+  set_text(Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format));
+
+  //Show a different color if the value is numeric, if that's specified:
+  if(layout_item->get_glom_type() == Field::TYPE_NUMERIC)
+  {
+    std::vector<Gtk::CellRenderer*> cells = get_cells();
+    if(cells.empty())
+      return;
+
+    Gtk::CellRendererText* cell = dynamic_cast<Gtk::CellRendererText*>(cells[0]);
+    if(!cell)
+      return;
+
+    const Glib::ustring fg_color = 
+    layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
+    if(fg_color.empty())
+    {
+      //GtkComboBox doesn't interpret "" as an unset. TODO: Fix that?
+      cell->property_foreground_set() = false;
+    }
+    else
+      cell->property_foreground() = fg_color;
+  }
 }
 
 void ComboGlom::set_text(const Glib::ustring& text)
@@ -151,7 +187,11 @@ void ComboGlom::set_text(const Glib::ustring& text)
 
     if(this_text == text)
     {
+      #ifndef GLOM_ENABLE_MAEMO
       set_active(iter);
+      #else
+      set_selected(iter);
+      #endif //GLOM_ENABLE_MAEMO
       return; //success
     }
   }
@@ -159,7 +199,11 @@ void ComboGlom::set_text(const Glib::ustring& text)
   g_warning("ComboGlom::set_text(): no item found for: %s", text.c_str());
 
   //Not found, so mark it as blank:
+  #ifndef GLOM_ENABLE_MAEMO
   unset_active();
+  #else
+  unselect();
+  #endif
 }
 
 Gnome::Gda::Value ComboGlom::get_value() const
@@ -174,10 +218,16 @@ Gnome::Gda::Value ComboGlom::get_value() const
 Glib::ustring ComboGlom::get_text() const
 {
   //Get the active row:
-  Gtk::TreeModel::iterator active_row = get_active();
-  if(active_row)
+  #ifndef GLOM_ENABLE_MAEMO
+  Gtk::TreeModel::iterator iter = get_active();
+  #else
+  ComboGlom* unconst = const_cast<ComboGlom*>(this);
+  Gtk::TreeModel::iterator iter = unconst->get_selected();
+  #endif //GLOM_ENABLE_MAEMO
+  
+  if(iter)
   {
-    Gtk::TreeModel::Row row = *active_row;
+    Gtk::TreeModel::Row row = *iter;
     return row[m_Columns.m_col_first];
   }
 
@@ -229,7 +279,12 @@ App_Glom* ComboGlom::get_application()
   return dynamic_cast<App_Glom*>(pWindow);
 }
 
+
+#ifndef GLOM_ENABLE_MAEMO
 void ComboGlom::on_changed()
+#else
+void ComboGlom::on_changed(int /* column */)
+#endif 
 {
 #ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   //Call base class:
@@ -238,7 +293,12 @@ void ComboGlom::on_changed()
 
   //This signal is emitted for every key press, but sometimes it's just to say that the active item has changed to "no active item",
   //if the text is not in the dropdown list:
+  #ifndef GLOM_ENABLE_MAEMO
   Gtk::TreeModel::iterator iter = get_active();
+  #else
+  Gtk::TreeModel::iterator iter = get_selected();
+  #endif //GLOM_ENABLE_MAEMO
+  
   if(iter)
   {
     //This is either a choice from the dropdown menu, or someone has typed in something that is in the drop-down menu.
